3 ms·
And with no threads: 49.6 ms ± 947 µs per loop. I’m pretty sure the time “savings” you are seeing here come from somewhere else. At a first glance, your copyin
by orf 7y ago
And with no threads: 49.6 ms ± 947 µs per loop.
I’m pretty sure the time “savings” you are seeing here come from somewhere else. At a first glance, your copying the huge list while submitting it to the thread pool, this has overhead. Maybe lots of smaller copies are faster on your machine.